#################################################################
# ________________________snow  depth____________________________
######################################################################
snow <- read.csv(".../Snow_depth_winter_1415.csv", header=T, sep=";")
#exclude plot N2
snow <- snow[!snow$plot=="N2",]
snow.model.west <- lm(log(snowdepth) ~ treatment, data=subset(snow, side=="west"))
Anova(snow.model.west, type="II", test.statistic="F")
HSD.test(snow.model.west, "treatment",  console=T) 


###############################################################################
# ________________________vegetation composition____________________________
#################################################################################
veg <- read.csv(".../vegetation_composition.csv", header=T, sep=";")
head(veg)
veg$X <- NULL    
veg$remarks <- NULL
#exclude plot N2
veg <- veg[!veg$plotnr=="N2",]
vegetation <- aggregate(percent_cover ~  functional_group * plotnr * treatment, FUN=sum, data=veg)
cover.model <- lmer(sqrt(percent_cover) ~ treatment * functional_group + (1|plotnr), data=subset(vegetation, !treatment=="fertilized"))
Anova(cover.model, type="II", test.statistic="F")
anova(cover.model)

# analyse for each functional type seperately
brypphyte.cover.model <- lm((percent_cover) ~ treatment, data=subset(vegetation, functional_group=="bryophyte" & !treatment=="fertilized"))
Anova(brypphyte.cover.model, type="II", test.statistic="F")

dwarfshrub.cover.model <- lm((percent_cover) ~ treatment, data=subset(vegetation, functional_group=="dwarf shrub"& !treatment=="fertilized"))
Anova(dwarfshrub.cover.model, type="II", test.statistic="F")

graminoid.cover.model <- lm(sqrt(percent_cover) ~ treatment, data=subset(vegetation, functional_group=="graminoid"& !treatment=="fertilized"))
Anova(graminoid.cover.model, type="II", test.statistic="F")

lichen.cover.model <- lm(rank(percent_cover) ~ treatment, data=subset(vegetation, functional_group=="lichen"& !treatment=="fertilized"))
Anova(lichen.cover.model, type="II", test.statistic="F")


###############################################################################
# ________________________ 15N content ____________________________
#################################################################################
N15 <- read.csv(".../15N_results.csv", sep=";", header=T)
#add mg15N/gN or similar, for that divide Atom% by 100 (that is then a fraction, i.e. g/g) then possibly convert to mg/g (*1000)
N15$mg15N_gN = (N15$FN/100)*1000
# plot No. 2 has the outlier in 20-25 cm depth, THUS EXCLUDE PLOT #2 FROM FURTHER ANALYSIS!
N15 <- subset(N15, plotnr!="N2")

N15soil.lm.spring <- lmer((mg15N_gN) ~ depth * treatment + (1|plotnr), data=subset(N15, type=="soil" & season=="spring"))
anova(N15soil.lm.spring)

N15soil.lm.autumn <- lmer((mg15N_gN) ~ depth * treatment + (1|plotnr), data=subset(N15, type=="soil" & season=="autumn"))
anova(N15soil.lm.autumn)

# because of skweded distribution, test only for the fertilized plots
N15plants <- lmer(rank(mg15N_gN) ~ species*season + (1|plotnr), data=subset(N15, type=="leaf"& treatment=="fertilized"))
Anova(N15plants, type="III", test.statistic="F")
difflsmeans(N15plants, test.effs="species")
difflsmeans(N15plants)


#################################################################################################################################################################################################
#######################################   ROOT LENGTH   ##########################################################################################################################################
####################################################################################
root_length <- read.csv(".../root_length.csv", header=T, sep=",")
root_length$X <- NULL
# exclude all fertilized plots
root_length <- subset(root_length, !treatment=="fertilized")
root_length$session=as.factor(root_length$session)
root_length.model <- lme(sqrt(length_area) ~ treatment* PFT * depth_class, random=~1|plotnr, data=subset(root_length, !depth_class=="60-110"))
anova(root_length.model)

#seperate per PFT because of interactions
root_length.model.HEATH <- lmer(sqrt(length_area) ~ treatment*depth_class + (1|plotnr), data=subset(root_length, !depth_class=="60-110" & PFT=="HEATHspec"))
anova(root_length.model.HEATH)
difflsmeans(root_length.model.HEATH)

root_length.model.GRASS <- lmer(sqrt(length_area) ~ treatment*depth_class + (1|plotnr), data=subset(root_length, !depth_class=="60-110" & PFT=="GRASS"))
anova(root_length.model.GRASS)
difflsmeans(root_length.model.GRASS)


######################################################################################################################################################################
##################################     ROOT MORTALITY IN ERIOPHORUM ROOTS     ############################################################################################
#########################################################################################################################################################################
root_mortality_depth_class_per_plot <- read.csv(".../root_mortality_depth_class_per_plot.csv", header=T, sep=",")
root_mortality_depth_class_per_plot$X <- NULL
#remove sessions #3 and #19, such that it is 1 year of mortality
root_mortality_depth_class_per_plot <- subset(root_mortality_depth_class_per_plot, !session=="3" & !session=="19")
# exclude the fertilized plots
root_mortality_depth_class_per_plot <- subset(root_mortality_depth_class_per_plot, !treatment=="fertilized")
### SUM UP PER PLOT TO ONE VALUE; IRRESPECTIVE OF SESSION:
root_mortality_depth_class_per_plot_total_sum <- aggregate(mortality_mg ~ depth_class * treatment * plotnr, data=root_mortality_depth_class_per_plot, FUN=sum)

root.mortalit.model.total <- lmer(rank(mortality_mg) ~ treatment * depth_class+ (1|plotnr), data=subset(root_mortality_depth_class_per_plot_total_sum, !depth_class=="60-end" & !treatment=="fertilized"))
anova(root.mortalit.model.total)

g <- aov(rank(mortality_mg) ~ treatment * depth_class, data=subset(root_mortality_depth_class_per_plot_total_sum, !depth_class=="60-end" & !treatment=="fertilized"))
TukeyHSD(g)


#############################################################################################################################################################################################################
##################################### ROOT GROWTH #######################################################################################################################################################
##################################################################################################################################################
root_growth_plot <- read.csv(".../root_growth_plot.csv", header=T, sep=",")
root_growth_plot$X <- NULL
root_growth_plot$session=as.factor(root_growth_plot$session)
#exclude the fertlized plots
root_growth_plot <- subset(root_growth_plot, !treatment=="fertilized")

# exclude the winter measurements (sess 10,11, 12 --> all have different time scales)
growth.model <- lmer(rank(growth_area) ~ treatment * session * depth_class * PFT + (1|plotnr), data=subset(root_growth_plot, !depth_class=="60-end" & !session=="10" & !session=="11" & !session=="12"))
Anova(growth.model, type="II", test.statistic="F")
anova(growth.model)

# seperate for each PFT
growth.model.GRASS <- lmer(rank(growth_area) ~ treatment * session * depth_class + (1|plotnr), data=subset(root_growth_plot, !depth_class=="60-end" & !session=="10" & !session=="11" & !session=="12" & PFT=="GRASS"))
Anova(growth.model.GRASS, type="II", test.statistic="F")
difflsmeans(growth.model.GRASS, test.effs="session")

#only include shallow active layer for shrubs (unbalanced otherwise, almost no roots in deep active layer)
growth.model.SHRUB <- lmer(sqrt(growth_area) ~ treatment * session  + (1|plotnr), data=subset(root_growth_plot, !depth_class=="60-end" & !depth_class=="30-60" & !session=="10" & !session=="11" & !session=="12" & PFT=="HEATHspec"))
Anova(growth.model.SHRUB, type="II", test.statistic="F")
difflsmeans(growth.model.SHRUB)
difflsmeans(growth.model.SHRUB, test.effs="treatment")


#######################################################################################################################################################
##################################       Deepest root GROWTH and ALD    ##############################################################################
#######################################################################################################################################################
root_growth <- read.csv(".../root_growth.csv", header=T, sep=",")
root_growth$X <- NULL
# __________________Data preparation_______________________________________#
# deepest root growth observed compared to ALD
deeprootgrowth <- subset(root_growth, growth_area>0)
#exclude the winter measurements
deeprootgrowth <- subset(deeprootgrowth, !session==10)
deeprootgrowth <- subset(deeprootgrowth, !session==11)
deeprootgrowth <- subset(deeprootgrowth, !session==12)
# exclude the fertilization plots
deeprootgrowth <- subset(deeprootgrowth, !treatment=="fertilized")

growthALD <- aggregate(depth_cm ~ treatment*plotnr*Tube*session*doy*PFT*ALD_interpolated_both_years_together, deeprootgrowth, FUN=max)

shrubs <- lm(depth_cm ~ ALD_interpolated_both_years_together, data=subset(growthALD, PFT=="HEATHspec"))
coefficients(shrubs)
summary(shrubs)
grass <- lm(depth_cm ~ ALD_interpolated_both_years_together, data=subset(growthALD, PFT=="GRASS"))
coefficients(grass)
summary(grass)
